@@ -48,63 +48,11 @@ module.exports = generators.Base.extend({
     },
     askForRoutes: function() { ionicUtils.routes.ask(this) },
     askForModels: function() { ionicUtils.models.ask(this) },
+    askForAuthentificationProvider: function() { ionicUtils.auth.ask(this) },
     /*
-    askForAnalytics: function askForAnalytics() {
-      var done = this.async();
-
-      this.prompt([{
-        type: 'confirm',
-        name: 'flurry',
-        message: 'Would you like to use Flurry Analytics?',
-        default: (typeof(this.options.flurry) !== 'undefined') ? this.options.flurry : false
-      }], function (props) {
-        this.flurry = this.options.selected.flurry = props.flurry;
-
-        done();
-      }.bind(this));
-    },
-    askForPush: function askForPush() {
-      var done = this.async();
-
-      this.prompt([{
-        type: 'confirm',
-        name: 'push',
-        message: 'Would you like to use Parse push notification?',
-        default: (typeof(this.options.push) !== 'undefined') ? this.options.push : false
-      }], function (props) {
-        this.push = this.options.selected.push = props.push;
-
-        done();
-      }.bind(this));
-    },
-    askForPlugins: function askForPlugins() {
-      var done = this.async();
-
-      if (this.options.plugins) {
-        ionicUtils.mergePlugins(this.options.plugins);
-      }
-
-      this.prompt(ionicUtils.plugins.prompts, function (props) {
-        this.plugins = this.options.selected.plugins = props.plugins;
-
-        done();
-      }.bind(this));
-    },*/
-    askForAuthentificationProvider: function askForAuthentificationProvider() {
-      var done = this.async();
-      /*if (this.options.auth) {
-        console.log('OPTIONS')
-        ionicUtils.mergeAuthProvider(this.options.auth);
-      }*/
-
-      this.prompt(ionicUtils.auth.prompts, function (props) {
-        console.log(props);        
-        this.auth = this.options.selected.auth = props.providers;
-        console.log('AUTH:');
-        console.log(this.auth);
-        done();
-      }.bind(this));
-    },
+    askForAnalytics: function() { ionicUtils.analytics.ask(this) },
+    askForPush: function() { ionicUtils.push.ask(this) },
+    askForPlugins: { ionicUtils.plugins.ask(this) },*/
     askForStarter: function askForStarter() {
       var done = this.async();
 
@@ -144,11 +92,12 @@ module.exports = generators.Base.extend({
       this.appName = mout.string.pascalCase(this.appName);
       this.appId = this.options.appId || 'com.example.' + this.appName;
       this.appPath = 'app';
-      this.ctrlPath = this.appPath + '/controllers/';
-      this.servicesPath = this.appPath + '/services/';
-      this.modelsPath = this.appPath + '/services/models/';
-      this.directivesPath = this.appPath + '/directives/';
-      this.viewPath = 'template/';
+      this.jsPath = this.appPath + '/js';
+      this.ctrlPath = this.jsPath + '/controllers/';
+      this.servicesPath = this.jsPath + '/services/';
+      this.modelsPath = this.servicesPath + 'models/';
+      this.directivesPath = this.jsPath + '/directives/';
+      this.viewPath = 'templates/';
       this.root = process.cwd() + '/' + this.appName;
 
       this.pkg = JSON.parse(this.readFileAsString(path.join(__dirname, '../package.json')));
@@ -188,85 +137,25 @@ module.exports = generators.Base.extend({
         } else {
           console.log(chalk.yellow('Created a new Cordova project with name "' + this.appName + '" and id "' + this.appId + '"'));
           mkdir.sync('local_plugins');
+          this.copy('scripts/modules.js', this.jsPath + 'modules.js');
+          this.scriptsFile.push(this.jsPath + 'modules.js');
+
+          // create module.js
+          var moduleFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/module.js'))
+          moduleFile = moduleFile.replace(new RegExp("{{APP_NAME}}", 'g'), this.appName);
+          var moduleFilePath = this.jsPath + 'modules.js'
+          this.write(ctrlFilePath, moduleFile);
+          this.scriptsFile.push(moduleFilePath);
         }
         done();
       }.bind(this));
     },
-    installModels: function installModels() { ionicUtils.models.install(this) },
-    installRoutes: function installRoutes() { ionicUtils.routes.install(this) },
-    installAuthProvider: function installAuthProvider() {
-      console.log('installAuthProvider');
-      console.log(this.auth);
-      if (this.auth) {
-        var done = this.async();
-        ionicUtils.auth.install(this, this.auth, done);
-      }
-    },
-    /*installPush: function installPush() {
-      if (this.push) {
-        var self = this;
-        var done = this.async();
-        self.prompt({
-          type    : 'input',
-          name    : 'APP_ID',
-          message : 'What\'s your Parse APP_ID',
-          store   : true
-        }, function(app_id) {
-          console.log(app_id);
-          self.prompt({
-            type    : 'input',
-            name    : 'CLIENT_ID',
-            message : 'What\'s your Parse CLIENT_ID',
-            store   : true
-          }, function(client_id) {
-            console.log(client_id);
-            self.directory('../templates/plugins/com.plugins.parsePushNotifications', 'local_plugins/com.plugins.parsePushNotifications');
-            self.lplugins.push('local_plugins/com.plugins.parsePushNotifications --variable APP_ID=' + app_id + ' --variable CLIENT_ID=' + client_id);
-            done();
-          });
-        });
-        
-      }
-    },
-    installFlurry: function installFlurry() {
-      if (this.flurry) {
-        var done = this.async();
-        var self = this;
-        self.prompt({
-            type    : 'input',
-            name    : 'FLURRY_ID',
-            message : 'What\'s your Flurry APP_ID',
-            store   : true
-          }, function(flurry_id) {
-            console.log(flurry_id);
-            self.directory('../templates/plugins/com.plugins.flurryLib', 'local_plugins/com.plugins.flurryLib');
-            self.lplugins.push('local_plugins/com.plugins.flurryLib' + ' --variable APP_ID=' + flurry_id );
-            done();
-          });
-        
-      }
-    },
-    installPlugins: function installPlugins() {
-      console.log(chalk.yellow('\nInstall plugins registered at plugins.cordova.io: ') + chalk.green('grunt plugin:add:org.apache.cordova.globalization'));
-      console.log(chalk.yellow('Or install plugins direct from source: ') + chalk.green('grunt plugin:add:https://github.com/apache/cordova-plugin-console.git\n'));
-      if (this.plugins.length > 0) {
-        console.log(chalk.yellow('Installing selected Cordova plugins, please wait.'));
-        
-        // Turns out plugin() doesn't accept a callback so we try/catch instead
-        try {
-          cordova.plugin('add', this.plugins);
-        } catch (e) {
-          console.log(e);
-          this.log.error(chalk.red('Please run `yo ionic` in an empty directory, or in that of an already existing cordova project.'));
-          process.exit(1);
-        }
-      }
-      if (this.lplugins.length > 0) {
-        for (var i = this.lplugins.length - 1; i >= 0; i--) {
-          var plugin = this.lplugins[i];
-        };
-      }
-    },
+    installModels: function installModels() { ionicUtils.models.install(this); },
+    installRoutes: function installRoutes() { ionicUtils.routes.install(this); },
+    installAuthProvider: function installAuthProvider() { ionicUtils.auth.install(this); },
+    /*installPush: function installPush() { ionicUtils.push.install(this); },
+    installFlurry: function installFlurry() { ionicUtils.analytics.install(this); },
+    installPlugins: function installPlugins()  { ionicUtils.plugins.install(this); },
   */
     installStarter: function installStarter() {
       console.log(chalk.yellow('Installing starter template. Please wait'));
@@ -330,8 +219,12 @@ module.exports = generators.Base.extend({
         this.indexFile = this.indexFile.replace(/<script src="lib\/ionic\/js\/ionic.bundle.js"><\/script>/g, "<!-- build:js scripts\/vendor.js -->\n    <!-- bower:js -->\n    <!-- endbower -->\n    <!-- endbuild -->");
       
        // Regex: User scripts (scripts.js)
+       var scripts = '';
+       for (var i = this.scriptsFile.length - 1; i >= 0; i--) {
+         scripts += "<script src=\"" + this.scriptsFile[i] + "\"><\/script>\n";
+       };
        this.indexFile = this.indexFile.replace(/<!-- your app's js -->/g,"<!-- your app's js -->\n    <!-- build:js scripts\/scripts.js -->");
-       this.indexFile = this.indexFile.replace(/<\/head>/g,"  <script src=\"scripts\/configuration.js\"><\/script>\n    <!-- endbuild -->\n  <\/head>");
+       this.indexFile = this.indexFile.replace(/<\/head>/g, scripts + "    <!-- endbuild -->\n  <\/head>");
        
        // Regex/Rename: Scripts path (Ionics 'js' to 'scripts')
        this.indexFile = this.indexFile.replace(/href="css/g,"href=\"styles");
