@@ -4,11 +4,12 @@ var path = require('path');
 var createService = function(self, provider) {
   var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/' + provider + 'AuthService.js'))
   file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);  
-  self.write(path.join(self.appPath, provider+'Service.js'), file);
+  var filePath = path.join(self.appPath, provider+'Service.js');
+  self.write(filePath, file);
+  self.scriptsFile.push(filePath);
 }
 
-module.exports = {
-  prompts: [{
+var prompt: [{
     type: 'checkbox',
     name: 'providers',
     message: 'Which Authentification provider would you like to include?',
@@ -27,16 +28,24 @@ module.exports = {
       name: 'Username/Password',
       checked: false
     }
-    ]
-  }],
-  install: function(self, choices, done) {
-    var promises = [];
+  ]
+}];
+
+module.exports = {
+  ask: function(self) {
+    var done = self.async();
+    self.prompt(prompt, function (props) {
+      self.auth = props.providers;
+      done();
+    }.bind(self));
+  },
+  install: function(self) {
+    var choices = self.auth;
+    var done = self.async();
     for (var i = choices.length - 1; i >= 0; i--) {
       console.log('Choice:' + choices[i]);
       createService(self, choices[i]);
     };
     done();
-  },
-
-
+  }
 };
