@@ -44,7 +44,9 @@ module.exports = {
       var modelFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/model.js'))
       modelFile = modelFile.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
       modelFile = modelFile.replace(new RegExp("{{MODEL}}", 'g'), m);
-      self.write(path.join(self.modelsPath, m + '.js'), modelFile);
+      var filePath = path.join(self.modelsPath, m + '.js');
+      self.write(filePath, modelFile);
+      self.scriptsFile.push(filePath);
     };
     done();
   },
