@@ -65,8 +65,10 @@ var generateConfigRoute = function(self, configRoutes, route) {
   var ctrlFile = self.readFileAsString(path.join(__dirname, '../templates/scripts/ctrl.js'))
   ctrlFile = ctrlFile.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
   ctrlFile = ctrlFile.replace(new RegExp("{{CTRL_NAME}}", 'g'), ctrl);
-  self.write(path.join(self.ctrlPath, ctrl+'.js'), ctrlFile);
+  var ctrlFilePath = path.join(self.ctrlPath, ctrl+'.js');
+  self.write(ctrlFilePath, ctrlFile);
   self.write(path.join(self.viewPath, view+'.html'), '');
+  self.scriptsFile.push(ctrlFilePath);
 }
 
 module.exports = {
@@ -98,8 +100,9 @@ module.exports = {
     };
     var file = self.readFileAsString(path.join(__dirname, '../templates/scripts/config.js'))
     file = file.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
-    file = file.replace(new RegExp("{{ROUTES}}", 'g') configRoutes);
+    file = file.replace(new RegExp("{{ROUTES}}", 'g'), configRoutes);
     self.write(path.join(self.appPath, 'config.js'), file);
+    self.scriptsFile.push('config.js');
     done();
   }
 };
